import { type ArrayCardinality, ZodArray, type ZodBoolean, ZodDiscriminatedUnion, ZodEffects, ZodLazy, type ZodLiteral, type ZodNull, ZodNullable, type ZodNumber, ZodObject, type ZodRawShape, ZodReadonly, type ZodString, ZodTuple, type ZodTypeAny, type ZodUndefined, type ZodUnion } from 'zod';
import { type CustomScalarSchema } from './custom-scalar.js';
export interface StrictObjectSchema<Shape extends ZodRawShape> extends Omit<ZodObject<Shape, 'strict'>, 'deepPartial' | 'keyof'> {
}
export declare function isStrictObjectSchema(schema: unknown): schema is StrictObjectSchema<FieldShape>;
interface EffectSchema<Schema extends ZodTypeAny> extends ZodEffects<Schema> {
}
type LiteralSchema = ZodLiteral<boolean> | ZodLiteral<null> | ZodLiteral<number> | ZodLiteral<string>;
type PrimitiveSchema = LiteralSchema | ZodBoolean | ZodNull | ZodNumber | ZodString | ZodUndefined;
export type FragmentTypeName = boolean | number | string | null;
export declare type FragmentUnionOptionSchema = ZodObject<FieldShape & {
    __typename: PrimitiveSchema;
}, 'strict'>;
export type FieldShape = {
    readonly [FieldName: string]: FieldSchema;
};
export type NonWrappedFieldSchema = CustomScalarSchema<ZodTypeAny> | PrimitiveSchema | StrictObjectSchema<FieldShape> | ZodArray<FieldSchema, ArrayCardinality> | ZodDiscriminatedUnion<'__typename', FragmentUnionOptionSchema[]> | ZodTuple<[FieldSchema, ...FieldSchema[]], FieldSchema | null> | ZodUnion<readonly [PrimitiveSchema, ...(readonly PrimitiveSchema[])]>;
export type WrappedFieldSchema = EffectSchema<FieldSchema> | ZodLazy<FieldSchema> | ZodNullable<FieldSchema> | ZodReadonly<FieldSchema>;
export type FieldSchema = NonWrappedFieldSchema | WrappedFieldSchema;
type UnwrappedChainResult = {
    unwrappedSchema: NonWrappedFieldSchema;
    wrapperElements: WrappedFieldSchema[];
};
export declare function unwrapFieldSchemaChain(parent: FieldSchema): UnwrappedChainResult;
export declare function unwrapFieldSchema(parent: FieldSchema): NonWrappedFieldSchema;
type QueryShape = Record<string, FieldSchema>;
export type QuerySchema = StrictObjectSchema<QueryShape> | ZodReadonly<StrictObjectSchema<QueryShape>>;
export type FieldSchemaTuple<Schema extends FieldSchema> = ZodTuple<[Schema, ...Schema[]], Schema | null>;
export type ObjectOrListSchema = FieldSchemaTuple<FieldSchema> | StrictObjectSchema<FieldShape> | ZodArray<FieldSchema, ArrayCardinality>;
export declare function isObjectOrListSchema(schema: FieldSchema): schema is ObjectOrListSchema;
export type FragmentsSchema = ZodDiscriminatedUnion<'__typename', FragmentUnionOptionSchema[]>;
export declare function isFragmentsSchema(schema: FieldSchema): schema is FragmentsSchema;
export type UnionOrListSchema = FieldSchemaTuple<FieldSchema> | FragmentsSchema | ZodArray<FieldSchema, ArrayCardinality>;
export declare function isUnionOrListSchema(schema: FieldSchema): schema is UnionOrListSchema;
export {};
//# sourceMappingURL=query-schema.d.ts.map