import { ZodArray, ZodDiscriminatedUnion, ZodEffects, ZodLazy, ZodNullable, ZodObject, ZodReadonly, ZodTuple } from 'zod';
import { isCustomScalarSchema } from './custom-scalar.js';
export function isStrictObjectSchema(schema) {
    return schema instanceof ZodObject;
}
function isWrappedFieldSchema(schema) {
    if (isCustomScalarSchema(schema)) {
        return false;
    }
    return schema instanceof ZodLazy || schema instanceof ZodEffects || schema instanceof ZodNullable ||
        schema instanceof ZodReadonly;
}
// eslint-disable-next-line max-statements,complexity -- no idea how to refactor for now
function recursiveUnwrapFieldSchemaChain(parent, currentChain) {
    let unwrapped = parent;
    if (!isWrappedFieldSchema(parent)) {
        return {
            unwrappedSchema: parent,
            wrapperElements: currentChain
        };
    }
    if (parent instanceof ZodLazy) {
        unwrapped = parent.schema;
    }
    else if (parent instanceof ZodEffects) {
        unwrapped = parent.innerType();
    }
    else if (parent instanceof ZodNullable) {
        unwrapped = parent.unwrap();
    }
    else if (parent instanceof ZodReadonly) {
        unwrapped = parent.unwrap();
    }
    if (isWrappedFieldSchema(unwrapped)) {
        return recursiveUnwrapFieldSchemaChain(unwrapped, [...currentChain, parent]);
    }
    return {
        unwrappedSchema: unwrapped,
        wrapperElements: [...currentChain, parent]
    };
}
export function unwrapFieldSchemaChain(parent) {
    return recursiveUnwrapFieldSchemaChain(parent, []);
}
export function unwrapFieldSchema(parent) {
    const result = unwrapFieldSchemaChain(parent);
    return result.unwrappedSchema;
}
export function isObjectOrListSchema(schema) {
    return isStrictObjectSchema(schema) || schema instanceof ZodArray || schema instanceof ZodTuple;
}
export function isFragmentsSchema(schema) {
    return schema instanceof ZodDiscriminatedUnion;
}
export function isUnionOrListSchema(schema) {
    return isFragmentsSchema(schema) || schema instanceof ZodArray || schema instanceof ZodTuple;
}
//# sourceMappingURL=query-schema.js.map